import kabbes_smart_documentation
import kabbes_client
import kabbes_pypi_builder

class Client( kabbes_smart_documentation.DocumentationGenerator ):

    _BASE_DICT = {}

    def __init__( self, dict={} ):

        d = {}
        d.update( Client._BASE_DICT )
        d.update( dict )

        self.Package = kabbes_client.Package( kabbes_smart_documentation._Dir, dict=d )
        cfg_sd = self.Package.cfg
        cfg_pypi = kabbes_pypi_builder.Client().cfg

        cfg_pypi.merge( cfg_sd )
        self.cfg = cfg_pypi

        kabbes_smart_documentation.DocumentationGenerator.__init__( self )




import kabbes_pypi_builder
import os

class DocumentationGenerator( kabbes_pypi_builder.PackageGenerator ):

    def __init__( self ):
        kabbes_pypi_builder.PackageGenerator.__init__( self )

    def generate_sphinx( self ):
        os.system( self.cfg['sphinx_script_Path'].read() ) 



from setuptools import setup

if __name__ == '__main__':
    setup(
        package_data={'kabbes_smart_documentation': 
        [ 
            'Templates/default/.github/workflows/*.yml',
            'Templates/sphinx/conf.py',
            'Templates/sphinx/index.rst',
            'Templates/sphinx/make.bat',
            'Templates/sphinx/Makefile',
            'CONFIG.json',
            'sphinx_script.sh'
        ]
        }
    )